@@ -1,10 +1,15 @@
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+/*******************************
+ Change personal information
+ (c) 1999 Jeremy Wise
+ GnomeICU
+********************************/
 
+/*** GnomeICU header files ***/
+#include "common.h"
+
+/*** Toplevel header files ***/
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <unistd.h>
 #include <netinet/in.h>
 #include <sys/types.h>
@@ -13,37 +18,23 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <sys/time.h>
-
 #include <fcntl.h>
 #include <time.h>
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
 #include <assert.h>
-
 #ifdef HAVE_SOCKS5
 #define SOCKS
 #include <socks.h>
 #endif
 
-#include <gdk/gdk.h>
-
-#include "tcp.h"
-
-#include "events.h"
-
-#include "gnomeicu.h"
-#include "gtkfunc.h"
-
-#include "pixmaps.h"
-#include "msg_queue.h"
-
-#include "applet.h"
-
-void changed( GtkWidget *widget, GnomePropertyBox *pb );
-gint clear_window( GtkWidget *widget, gpointer data );
-void apply_changes( GtkWidget *widget, gpointer data );
+/*** Local function declarations ***/
+static void changed( GtkWidget *widget, GnomePropertyBox *pb );
+static gint clear_window( GtkWidget *widget, gpointer data );
+static void apply_changes( GtkWidget *widget, gpointer data );
 
+/*** Global functions ***/
 void change_info_window( GtkWidget *widget, gpointer data )
 {
 	GtkWidget *label;
@@ -62,6 +53,8 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	else
 		return;
 
+	gtk_window_set_title( GTK_WINDOW( our_info->window ), _("GnomeICU: User Information") );
+
 	gtk_signal_connect( GTK_OBJECT( our_info->window ), "apply",
 	                    (GtkSignalFunc)apply_changes, NULL );
 
@@ -76,61 +69,61 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	                                             1900.0F, 1999.0F, 1.0F, 100.0F,
 	                                             0.0F );
 
-	gender = g_list_append( gender, "Male" );
-	gender = g_list_append( gender, "Female" );
-	gender = g_list_append( gender, "Not specified" );
+	gender = g_list_prepend( gender, _("Not specified") );
+	gender = g_list_prepend( gender, _("Female") );
+	gender = g_list_prepend( gender, _("Male") );
 
-	months = g_list_append( months, "January" );
-	months = g_list_append( months, "February" );
-	months = g_list_append( months, "March" );
-	months = g_list_append( months, "April" );
-	months = g_list_append( months, "May" );
-	months = g_list_append( months, "June" );
-	months = g_list_append( months, "July" );
-	months = g_list_append( months, "August" );
-	months = g_list_append( months, "September" );
-	months = g_list_append( months, "October" );
-	months = g_list_append( months, "November" );
-	months = g_list_append( months, "December" );
+	months = g_list_prepend( months, _("December") );
+	months = g_list_prepend( months, _("November") );
+	months = g_list_prepend( months, _("October") );
+	months = g_list_prepend( months, _("September") );
+	months = g_list_prepend( months, _("August") );
+	months = g_list_prepend( months, _("July") );
+	months = g_list_prepend( months, _("June") );
+	months = g_list_prepend( months, _("May") );
+	months = g_list_prepend( months, _("April") );
+	months = g_list_prepend( months, _("March") );
+	months = g_list_prepend( months, _("February") );
+	months = g_list_prepend( months, _("January") );
 
 /** General Tab **/
 
 	table = gtk_table_new( 5, 7, FALSE );
 	gtk_container_set_border_width( GTK_CONTAINER( table ), 7 );
 	gnome_property_box_append_page( GNOME_PROPERTY_BOX( our_info->window ), table,
-	                                gtk_label_new( "General" ) );
+	                                gtk_label_new( _("General") ) );
 
-	label = gtk_label_new( "UIN:" );
+	label = gtk_label_new( _("UIN:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Nick:" );
+	label = gtk_label_new( _("Nick:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 		
-	label = gtk_label_new( "F. Name:" );
+	label = gtk_label_new( _("F. Name:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "L. Name:" );
+	label = gtk_label_new( _("L. Name:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 		
-	label = gtk_label_new( "Sex:" );
+	label = gtk_label_new( _("Sex:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Age:" );
+	label = gtk_label_new( _("Age:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 3, 4, 2, 3, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Birthday:" );
+	label = gtk_label_new( _("Birthday:") );
 	gtk_misc_set_alignment( GTK_MISC( label ) , 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 4, 5, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
@@ -177,13 +170,13 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_combo_set_popdown_strings( GTK_COMBO( our_info->w_sex ), gender );
 	if( our_info->sex == MALE )
 		gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ),
-		                    "Male" );
+		                    _("Male") );
 	else if( our_info->sex == FEMALE )
 		gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ),
-		                    "Female" );
+		                    _("Female") );
 	else
 		gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ),
-		                    "Not specified" );
+		                    _("Not specified") );
 
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_sex,
 	                  1, 2, 2, 3, GTK_FILL, GTK_FILL, 5, 5 );
@@ -204,11 +197,11 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_signal_connect( GTK_OBJECT( our_info->w_age ), "changed", changed, our_info->window );
 	gtk_widget_show( our_info->w_age );
 
-	our_info->w_auth = gtk_check_button_new_with_label( "Require Auth" );
+	our_info->w_auth = gtk_check_button_new_with_label( _("Require Auth") );
 	gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( our_info->w_auth ), our_info->auth );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_auth,
 	                  1, 2, 3, 4, GTK_FILL, GTK_FILL, 5, 5 );
+	gtk_signal_connect( GTK_OBJECT( our_info->w_auth ), "toggled", changed, our_info->window );
 	gtk_widget_show( our_info->w_auth );
 
 	hbox = gtk_hbox_new( 0, FALSE );
@@ -222,43 +215,43 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	switch( our_info->birth_month )
 	{
 		case 1:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "January" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("January") );
 			break;
 		case 2:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "February" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("February") );
 			break;
 		case 3:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "March" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("March") );
 			break;
 		case 4:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "April" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("April") );
 			break;
 		case 5:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "May" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("May") );
 			break;
 		case 6:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "June" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("June") );
 			break;
 		case 7:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "July" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("July") );
 			break;
 		case 8:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "August" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("August") );
 			break;
 		case 9:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "September" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("September") );
 			break;
 		case 10:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "October" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("October") );
 			break;
 		case 11:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "November" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("November") );
 			break;
 		case 12:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "December" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("December") );
 			break;
 		default:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), "January" );
+			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("January") );
 	}
 
 	gtk_box_pack_start( GTK_BOX( hbox ), our_info->w_birth_month, FALSE, FALSE, 0 );
@@ -292,36 +285,35 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	table = gtk_table_new( 6, 2, FALSE );
 	gtk_container_set_border_width( GTK_CONTAINER( table ), 7 );
 	gnome_property_box_append_page( GNOME_PROPERTY_BOX( our_info->window ), table,
-	                                gtk_label_new( "Internet" ) );
+	                                gtk_label_new( _("Internet") ) );
 
-	label = gtk_label_new( "IP:" );
+	label = gtk_label_new( _("IP:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Port:" );
+	label = gtk_label_new( _("Port:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Email:" );
+	label = gtk_label_new( _("Email:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Email 2:" );
+	label = gtk_label_new( _("Other Email:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 3, 4, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Email 3:" );
+	label = gtk_label_new( _("Old Email:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 4, 5, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
 	our_info->w_ip = gtk_entry_new();
 	gtk_entry_set_text( GTK_ENTRY( our_info->w_ip ), our_info->ip );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_ip,
 	                  1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 5 );
 	gtk_entry_set_editable( GTK_ENTRY( our_info->w_ip ), FALSE );
@@ -329,7 +321,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 
 	our_info->w_port = gtk_entry_new();
 	gtk_entry_set_text( GTK_ENTRY( our_info->w_port ), our_info->port );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_port,
 	                  1, 2, 1, 2, GTK_FILL, GTK_FILL, 5, 5 );
 	gtk_entry_set_editable( GTK_ENTRY( our_info->w_port ), FALSE );
@@ -337,7 +328,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 
 	our_info->w_email = gtk_entry_new();
 	gtk_entry_set_text( GTK_ENTRY( our_info->w_email ), our_info->email );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_email,
 	                  1, 2, 2, 3, GTK_FILL, GTK_FILL, 5, 5 );
 	gtk_widget_set_usize( our_info->w_email, 200, 0 );
@@ -347,7 +337,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 
 	our_info->w_email2 = gtk_entry_new();
 	gtk_entry_set_text( GTK_ENTRY( our_info->w_email2 ), our_info->email2 );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_email2,
 	                  1, 2, 3, 4, GTK_FILL, GTK_FILL, 5, 5 );
 	gtk_widget_set_usize( our_info->w_email2, 200, 0 );
@@ -357,7 +346,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 
 	our_info->w_email3 = gtk_entry_new();
 	gtk_entry_set_text( GTK_ENTRY( our_info->w_email3 ), our_info->email3 );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_email3,
 	                  1, 2, 4, 5, GTK_FILL, GTK_FILL, 5, 5 );
 	gtk_widget_set_usize( our_info->w_email3, 200, 0 );
@@ -365,11 +353,11 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_signal_connect( GTK_OBJECT( our_info->w_email3 ), "changed", changed, our_info->window );
 	gtk_widget_show( our_info->w_email3 );
 
-	our_info->w_hide_email = gtk_check_button_new_with_label( "Hide Email" );
+	our_info->w_hide_email = gtk_check_button_new_with_label( _("Hide Email") );
 	gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( our_info->w_hide_email ), our_info->hide_email );
-
 	gtk_table_attach( GTK_TABLE( table ), our_info->w_hide_email,
 	                  1, 2, 5, 6, GTK_FILL, GTK_FILL, 5, 5 );
+	gtk_signal_connect( GTK_OBJECT( our_info->w_hide_email ), "toggled", changed, our_info->window );
 	gtk_widget_show( our_info->w_hide_email );
 
 	gtk_widget_show( table );
@@ -378,49 +366,49 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	table = gtk_table_new( 9, 2, FALSE );
 	gtk_container_set_border_width( GTK_CONTAINER( table ), 7 );
 	gnome_property_box_append_page( GNOME_PROPERTY_BOX( our_info->window ), table,
-	                          gtk_label_new( "Location" ) );
+	                          gtk_label_new( _("Location") ) );
 
-	label = gtk_label_new( "Phone:" );
+	label = gtk_label_new( _("Phone:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Fax:" );
+	label = gtk_label_new( _("Fax:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Cellular:" );
+	label = gtk_label_new( _("Cellular:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Street:" );
+	label = gtk_label_new( _("Street:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 3, 4, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "City:" );
+	label = gtk_label_new( _("City:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 4, 5, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "State:" );
+	label = gtk_label_new( _("State:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 5, 6, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Zip:" );
+	label = gtk_label_new( _("Zip:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 6, 7, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Country:" );
+	label = gtk_label_new( _("Country:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 7, 8, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "Time Zone:" );
+	label = gtk_label_new( _("Time Zone:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 8, 9, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
@@ -526,14 +514,14 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	table = gtk_table_new( 3, 3, FALSE );
 	gtk_container_set_border_width( GTK_CONTAINER( table ), 7 );
 	gnome_property_box_append_page( GNOME_PROPERTY_BOX( our_info->window ), table,
-	                                gtk_label_new( "About" ) );
+	                                gtk_label_new( _("About") ) );
 
-	label = gtk_label_new( "Home Page:" );
+	label = gtk_label_new( _("Home Page:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 1, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
 
-	label = gtk_label_new( "About:" );
+	label = gtk_label_new( _("About:") );
 	gtk_misc_set_alignment( GTK_MISC( label ), 0, 1 );
 	gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0 );
 	gtk_widget_show( label );
@@ -547,7 +535,7 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_signal_connect( GTK_OBJECT( our_info->w_homepage ), "changed", changed, our_info->window );
 	gtk_widget_show( our_info->w_homepage );
 
-	button = gtk_button_new_with_label( "View" );
+	button = gtk_button_new_with_label( _("View") );
 	gtk_table_attach( GTK_TABLE( table ), button,
 	                  2, 3, 0, 1, GTK_FILL, 0, 0, 0 );
 
@@ -588,11 +576,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_widget_show( our_info->window );
 }
 
-void display_url_from_entry( GtkWidget *widget, GtkEntry *entry )
-{
-	display_url( NULL, gtk_entry_get_text( entry ) );
-}
-
 void changed( GtkWidget *widget, GnomePropertyBox *pb )
 {
 	gnome_property_box_changed( pb );
@@ -606,21 +589,18 @@ gint clear_window( GtkWidget *widget, gpointer data )
 
 void apply_changes( GtkWidget *widget, gpointer data )
 {
-	if( our_info->nick != NULL )
-		g_free( our_info->nick );
+	g_free( our_info->nick );
 	our_info->nick = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_nick ) ) );
 
-	if( our_info->first != NULL )
-		g_free( our_info->first );
+	g_free( our_info->first );
 	our_info->first = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_first ) ) );
 
-	if( our_info->last != NULL )
-		g_free( our_info->last );
+	g_free( our_info->last );
 	our_info->last = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_last ) ) );
 
-	if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ) ), "Male" ) )
+	if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ) ), _("Male") ) )
 		our_info->sex = MALE;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ) ), "Female" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_sex )->entry ) ), _("Female") ) )
 		our_info->sex = FEMALE;
 	else
 		our_info->sex = NOT_SPECIFIED;
@@ -633,67 +613,58 @@ void apply_changes( GtkWidget *widget, gpointer data )
 
 	our_info->birth_day = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( our_info->w_birth_day ) );
 
-	if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "January" ) )
+	if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("January") ) )
 		our_info->birth_month = 1;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "February" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("February") ) )
 		our_info->birth_month = 2;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "March" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("March") ) )
 		our_info->birth_month = 3;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "April" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("April") ) )
 		our_info->birth_month = 4;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "May" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("May") ) )
 		our_info->birth_month = 5;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "June" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("June") ) )
 		our_info->birth_month = 6;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "July" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("July") ) )
 		our_info->birth_month = 7;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "August" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("August") ) )
 		our_info->birth_month = 8;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "September" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("September") ) )
 		our_info->birth_month = 9;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "October" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("October") ) )
 		our_info->birth_month = 10;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "November" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("November") ) )
 		our_info->birth_month = 11;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), "December" ) )
+	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("December") ) )
 		our_info->birth_month = 12;
 
-	if( our_info->email != NULL )
-		g_free( our_info->email );
+	g_free( our_info->email );
 	our_info->email = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_email ) ) );
 
-	if( our_info->email2 != NULL )
-		g_free( our_info->email2 );
+	g_free( our_info->email2 );
 	our_info->email2 = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_email2 ) ) );
 
-	if( our_info->email3 != NULL )
-		g_free( our_info->email3 );
+	g_free( our_info->email3 );
 	our_info->email3 = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_email3 ) ) );
 
 	our_info->hide_email = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( our_info->w_hide_email ));
 
-	if( our_info->phone != NULL )
-		g_free( our_info->phone );
+	g_free( our_info->phone );
 	our_info->phone = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_phone ) ) );
 
-	if( our_info->fax != NULL )
-		g_free( our_info->fax );
+	g_free( our_info->fax );
 	our_info->fax = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_fax ) ) );
 
-	if( our_info->cellular != NULL )
-		g_free( our_info->cellular );
+	g_free( our_info->cellular );
 	our_info->cellular = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_cellular ) ) );
 
-	if( our_info->street != NULL )
-		g_free( our_info->street );
+	g_free( our_info->street );
 	our_info->street = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_street ) ) );
 
-	if( our_info->city != NULL )
-		g_free( our_info->city );
+	g_free( our_info->city );
 	our_info->city = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_city ) ) );
 
-	if( our_info->state != NULL )
-		g_free( our_info->state );
+	g_free( our_info->state );
 	our_info->state = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_state ) ) );
 
 	our_info->zip = atoi( gtk_entry_get_text( GTK_ENTRY( our_info->w_zip ) ) );
@@ -702,13 +673,11 @@ void apply_changes( GtkWidget *widget, gpointer data )
 
 	our_info->c_status = Get_Time_Zone( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_c_status )->entry ) ) );
 
-	if( our_info->homepage != NULL )
-		g_free( our_info->homepage );
+	g_free( our_info->homepage );
 	our_info->homepage = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_homepage ) ) );
 
-	if( our_info->about != NULL )
-		g_free( our_info->about );
-	our_info->about = g_strdup( gtk_editable_get_chars( GTK_EDITABLE( our_info->w_about ), 0, -1 ) );
+	g_free( our_info->about );
+	our_info->about = gtk_editable_get_chars( GTK_EDITABLE( our_info->w_about ), 0, -1 );
 
-	Update_User_Info( MainData->sok );
+	Update_User_Info();
 }
