@@ -1,9 +1,13 @@
-/*
- *  ICQ (sound) Events 
- */
+/*******************************   
+ Handling of ICQ (sound) events   
+ (c) 1999 Jeremy Wise
+ GnomeICU
+********************************/
+   
+#ifndef __ICQ_EVENTS_H__
+#define  __ICQ_EVENTS_H__
 
-#ifndef __ICQ_EVENTS__
-#define  __ICQ_EVENTS__
+#include "common.h"
 
 typedef enum 
 {
@@ -16,9 +20,10 @@ typedef enum
   EV_AUTHREQ,   /* Request for authorization received */
   EV_AUTH,      /* Authorize notification */
   EV_FILEREQ,   /* Incoming file */
-  EV_LISTADD    /* Added to list */
+  EV_LISTADD,   /* Added to list */
+  EV_CONTLIST   /* Received Contact List */
 } ICQEvType;
 
-void gnomeicu_event(ICQEvType);
+void gnomeicu_event( ICQEvType event );
 
-#endif /*__ICQ_EVENTS__*/
+#endif /* __ICQ_EVENTS_H__ */
