@@ -1,8 +1,17 @@
-#include "gnomeicu.h"
-#include <gtk/gtk.h>
+/*******************************
+ Logging functions
+ (c) 1999 Jeremy Wise
+ GnomeICU
+********************************/
+
+/*** GnomeICU header files ***/
+#include "common.h"
+
+/*** Toplevel header files ***/
 #include <time.h>
 
-void log_window_add( char *statement, int stamped, int uin )
+/*** Global functions ***/
+void log_window_add( const gchar *statement, UIN_T uin )
 {
 	char *strings[4];
 	char who[32];
@@ -10,10 +19,11 @@ void log_window_add( char *statement, int stamped, int uin )
 	struct tm *my_tm;
 	char ptime[16];
 	char pdate[16];
-	int cx;
 	char *halves[] = { "AM", "PM" };
 	int half = 0;
 
+	GSList *contact;
+
 #ifdef TRACE_FUNCTION
 	g_print( "log_window_add\n" );
 #endif
@@ -21,7 +31,7 @@ void log_window_add( char *statement, int stamped, int uin )
 	strings[ 0 ] = ptime;
 	strings[ 1 ] = pdate;
 	strings[ 2 ] = who;
-	strings[ 3 ] = statement;
+	strings[ 3 ] = (gchar*)statement;
 
 	time( &timedate );
 	my_tm = localtime( &timedate );
@@ -35,18 +45,21 @@ void log_window_add( char *statement, int stamped, int uin )
 	sprintf( ptime, "%02d:%02d:%02d %s", my_tm->tm_hour, my_tm->tm_min,
 	         my_tm->tm_sec, halves[ half ] );
 	sprintf( pdate, "%02d/%02d/%d", my_tm->tm_mon + 1, my_tm->tm_mday,
-	         my_tm->tm_year );
+	         my_tm->tm_year + 1900 );
 
-	for( cx = 0; cx < Num_Contacts; cx ++ )
+	contact = Contacts;
+
+	while( contact != NULL )
 	{
-		if( uin == Contacts[ cx ].uin )
+		if( uin == ((CONTACT_PTR)contact->data)->uin )
 		{
-			sprintf( who, "%s", Contacts[ cx ].nick );
+			sprintf( who, "%s", ((CONTACT_PTR)contact->data)->nick );
 			break;
 		}
+		contact = contact->next;
 	}
 	
-	if( cx == Num_Contacts )
+	if( contact == NULL )
 	{
 		sprintf( who, "%d", uin );
 	}
