@@ -1,5 +1,11 @@
-#ifndef MSG_QUEUE_H
-#define MSG_QUEUE_H
+/*****************************
+ Resends un-ack'd packets
+ (c) 1999 Jeremy Wise
+ GnomeICU
+******************************/
+
+#ifndef __MSG_QUEUE_H__
+#define __MSG_QUEUE_H__
 
 #include "datatype.h"
 
@@ -32,4 +38,4 @@ void msg_queue_push( struct msg *new_msg );
 void Check_Queue( WORD seq );
 void msg_queue_clear( void );
 
-#endif
+#endif /* __MSG_QUEUE_H__ */
