@@ -1,3 +1,4 @@
+extern GdkPixmap *still_eyes_pixmap;
 extern GdkPixmap *icon_blank_pixmap;
 extern GdkPixmap *icon_message_pixmap;
 extern GdkPixmap *icon_url_pixmap;
@@ -11,10 +12,15 @@ extern GdkPixmap *icon_inv_pixmap;
 extern GdkPixmap *icon_online_pixmap;
 extern GdkPixmap *icon_offline_pixmap;
 extern GdkPixmap *icon_chat_pixmap;
-extern GdkPixmap *icon_chat2_pixmap;
 extern GdkPixmap *icon_file_pixmap;
 extern GdkPixmap *icon_info_pixmap;
-extern GdkPixmap *nomess_pixmap;
+extern GdkPixmap *icon_contact_pixmap;
+extern GdkPixmap *icon_hist_pixmap;
+extern GdkPixmap *icon_ok_pixmap;
+extern GdkPixmap *icon_cancel_pixmap;
+extern GdkPixmap *icon_rename_pixmap;
+
+extern GdkBitmap *still_eyes_bitmap;
 extern GdkBitmap *icon_blank_bitmap;
 extern GdkBitmap *icon_message_bitmap;
 extern GdkBitmap *icon_url_bitmap;
@@ -28,7 +34,10 @@ extern GdkBitmap *icon_inv_bitmap;
 extern GdkBitmap *icon_online_bitmap;
 extern GdkBitmap *icon_offline_bitmap;
 extern GdkBitmap *icon_chat_bitmap;
-extern GdkBitmap *icon_chat2_bitmap;
 extern GdkBitmap *icon_file_bitmap;
 extern GdkBitmap *icon_info_bitmap;
-extern GdkBitmap *nomess_bitmap;
+extern GdkBitmap *icon_contact_bitmap;
+extern GdkBitmap *icon_hist_bitmap;
+extern GdkBitmap *icon_ok_bitmap;
+extern GdkBitmap *icon_cancel_bitmap;
+extern GdkBitmap *icon_rename_bitmap;
