@@ -1,13 +1,13 @@
-/*
- * Send Message Function
- *
- * Original Author: zed@mentasm.com
- */
+/*************************************
+ Sends various messages to the server
+ (c) 1999 Jeremy Wise 
+ GnomeICU
+**************************************/
 
-#include "../config.h"
- 
-#include "datatype.h"
-#include "gnomeicu.h"
+/*** GnomeICU header files ***/
+#include "common.h"
+
+/*** Toplevel header files ***/
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -16,29 +16,22 @@
 #include <string.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-
 #ifdef HAVE_SOCKS5
 #define SOCKS 1
 #include <socks.h>
 #endif
 
-#include "tcp.h"
-#include "sendmsg.h"
-#include "msg_queue.h"
-
-#include "applet.h"
-
 int search_wait;
-ProgressData *search_pdata;
 
 DWORD our_session;
 
-char *cr_convert( char *text );
-void Wrinkle( void *buf, size_t len );
-void Gen_Checksum( BYTE * buf, DWORD len );
-DWORD Scramble_cc( DWORD cc );
-static size_t SOCKWRITE_LOW( SOK_T sok, void * ptr, size_t len );
-void Update_More_User_Info( SOK_T sok, MORE_INFO_PTR user);
+/*** Local function declarations ***/
+static char *cr_convert( const gchar *text );
+static void Wrinkle( void *buf, size_t len );
+static void Gen_Checksum( BYTE * buf, DWORD len );
+static DWORD Scramble_cc( DWORD cc );
+static size_t SOCKWRITE_LOW( void * ptr, size_t len, gchar *charid );
+/*void Update_More_User_Info( MORE_INFO_PTR user);*/
 
 /********************************************************
 The following data constitutes fair use for compatibility.
@@ -62,10 +55,13 @@ static const BYTE table[] = {
  0x47, 0x43, 0x69 , 0x48 , 0x33 , 0x51 , 0x54 , 0x5D , 0x6E , 0x3C , 0x31 , 0x64 , 0x35 , 0x5A , 0x00 , 0x00,
 };
 
+/*** Global functions ***/
+
+
 /****************************************************************
 Checks if packets are waiting to be resent and sends them.
 *****************************************************************/
-void Do_Resend( SOK_T sok )
+void Do_Resend( void )
 {
 	struct msg *queued_msg;
 	SIMPLE_MESSAGE_PTR s_mesg;
@@ -76,9 +72,12 @@ void Do_Resend( SOK_T sok )
 	char url_desc[1024], url_data[1024];
 	net_icq_pak pak;
 	int old_status;
-	int cx;
 
-	ProgressData *pdata = NULL;
+	GSList *contact;
+
+#ifdef TRACE_FUNCTION
+	g_print( "Do_Resend\n" );
+#endif
 
 	if ((queued_msg = msg_queue_pop()) != NULL)
 	{
@@ -88,7 +87,7 @@ void Do_Resend( SOK_T sok )
 			temp = g_malloc( queued_msg->len + 3 );
 			g_assert( temp != NULL );
 			memcpy( temp, queued_msg->body, queued_msg->len);
-			SOCKWRITE_LOW(sok, temp, queued_msg->len);
+			SOCKWRITE_LOW( temp, queued_msg->len, "RESEND" );
 			g_free(temp);
 			queued_msg->exp_time = time(NULL) + 10; 
 			msg_queue_push( queued_msg );
@@ -109,69 +108,64 @@ void Do_Resend( SOK_T sok )
 					if ( tmp != NULL )
 					{
 						*tmp = 0;
-						rus_conv( RUS_WIN_KOI, data);
 						strcpy(url_desc, data);
 						tmp++;
 						data = tmp;
-						rus_conv( RUS_WIN_KOI, data);
 						strcpy(url_data, data);
 					}
 				}
-				else if ( type == NORM_MESS || type == MRNORM_MESS )
-				{
-					rus_conv( RUS_WIN_KOI, data); 
-				}
 			}
 			else
 			{
 				if( ( CMD_LOGIN == Chars_2_Word( pak.head.cmd ) ) ||
 				    ( CMD_KEEP_ALIVE == Chars_2_Word( pak.head.cmd ) ) )
 				{
-					log_window_add( "Connection unreliable - reconnecting", 1, our_info->uin );
-					Time_Stamp();
+					log_window_add( _("Connection unreliable - reconnecting"), our_info->uin );
 					Quit = TRUE;
 					if( Connected )
 					{
 						old_status = Current_Status;
 						Current_Status = STATUS_OFFLINE;
-						Quit_ICQ( MainData->sok );
+						Quit_ICQ();
 						if( udp_gdk_input )
 						{
 							gdk_input_remove( udp_gdk_input );
 							udp_gdk_input = 0;
 						}
-						for( cx = 0; cx < Num_Contacts; cx ++ )
+
+						contact = Contacts;
+
+						while( contact != NULL )
 						{
-							Contacts[ cx ].last_status = Contacts[ cx ].status;
-							Contacts[ cx ].status = STATUS_OFFLINE;
+							((CONTACT_PTR)contact->data)->last_status = ((CONTACT_PTR)contact->data)->status;
+							((CONTACT_PTR)contact->data)->status = STATUS_OFFLINE;
+							contact = contact->next;
 						}
-						Show_Quick_Status( MainData );
-						seq_num = 0;
-						memset( serv_mess, FALSE, 1024 );
-						close( MainData->sok );
+						Show_Quick_Status();
+						seq_num = 1;
+						if( MainData->sok )
+							close( MainData->sok );
 
 						Connected = FALSE;
 
 						ready_set();
 
-						if( applet_toggle )
+						if( toggles->applet )
 						{
-							applet_update( Current_Status, NULL, MainData );
+							applet_update( Current_Status, NULL );
 						}
 
 						msg_queue_clear();
 
-						Current_Status = old_status;
+						Current_Status = old_status | (toggles->webpresence*0x10000);
 						Done_Login = FALSE;
 						MainData->sok = Connect_Remote( server, remote_port, STDERR );
 						if( MainData->sok > 0 )
 						{
 							udp_gdk_input = gdk_input_add( MainData->sok, GDK_INPUT_READ, (GdkInputFunction) icq_refresh, MainData );
 							Connected = TRUE;
-							connecting = show_wait( "Connecting to Server", pdata );
-							gtk_statusbar_push( GTK_STATUSBAR( statusbar ), 1, " Connecting to Server..." );
 
-							Login( MainData->sok, passwd, our_ip, our_port );
+							Login( passwd, our_ip, our_port );
 						}
 						else
 						{
@@ -194,56 +188,25 @@ void Do_Resend( SOK_T sok )
 		}
 		else
 		{
-			next_resend = INT_MAX;
+			next_resend = G_MAXINT;
 		}
 	}
 	else
    {
-		next_resend = INT_MAX;
+		next_resend = G_MAXINT;
 	}
 }
 
-char *cr_convert( char *text )
-{
-	char *t;
-	int cx, cy;
-	
-	cy = 0;
-	for( cx = 0; cx < strlen( text ); cx ++ )
-	{
-		if( text[ cx ] == '\n' )
-			cy ++;
-	}
-	
-	t = g_malloc( strlen( text ) + cy + 1 );
-
-	cy = 0;
-	for( cx = 0; cx < strlen( text ); cx ++ )
-	{
-		if( text[ cx ] != '\n' )
-			t[ cy ++ ] = text[ cx ];
-		else
-		{
-			t[ cy ++ ] = '\r';
-			t[ cy ++ ] = '\n';
-		}
-	}
-
-	t[ cy ] = 0x00;
-	
-	return t;
-}
-
 /*
  * Send a message thru the Server to the UIN
  * 'text' is the message
  */
-void icq_sendmsg( SOK_T sok, DWORD uin, char *text, struct sokandlb *data, int forced )
+void icq_sendmsg( UIN_T uin, const gchar *text, gboolean forced )
 {
 	SIMPLE_MESSAGE msg;
 	net_icq_pak pak;
 	int size, len; 
-	char *new_text;
+	gchar *new_text;
 
 #ifdef TRACE_FUNCTION
 	g_print( "icq_sendmsg\n" );
@@ -263,15 +226,17 @@ void icq_sendmsg( SOK_T sok, DWORD uin, char *text, struct sokandlb *data, int f
 	/* Add statement to personal history file */
 	add_outgoing_to_history( uin, new_text );
 
-	rus_conv( RUS_KOI_WIN, new_text );
-	if( !forced && !force_toggle && TCPSendMessage( uin, new_text, data ) )
+	if( !forced && !toggles->force && TCPSendMessage( uin, new_text) )
 	{
-		log_window_add( "Sent Message (TCP)", 1, uin );
+		log_window_add(_("Sent Message (TCP)"), uin );
 		g_free( new_text );
 		return;
 	}
 
-	log_window_add( "Sent Message (UDP)", 1, uin );
+	if( strlen( new_text ) + 1 > MAX_UDP_MESSAGE_LENGTH )
+		new_text[ MAX_UDP_MESSAGE_LENGTH ] = 0;
+
+	log_window_add(_("Sent Message (UDP)"), uin );
 
 	len = strlen(new_text);
 	Word_2_Chars( pak.head.ver, ICQ_VER );
@@ -288,97 +253,43 @@ void icq_sendmsg( SOK_T sok, DWORD uin, char *text, struct sokandlb *data, int f
 
 	size = sizeof( msg ) + len + 1;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_SENDM(MSG)");
 
 	g_free( new_text );
 }
 
-void icq_reverse_tcp( DWORD uin, int port )
-{
-	net_icq_pak pak;
-
-	struct
-	{
-		BYTE l_uin[4]; /* Local UIN */
-		BYTE r_uin[4]; /* Remote UIN */
-		BYTE ip[4];
-		BYTE porta[4];
-		BYTE four;
-		BYTE zero[4];
-		BYTE portb[4];
-		BYTE version[2];
-	} data;
-
-#ifdef TRACE_FUNCTION
-	g_print( "icq_reverse_tcp\n" );
-#endif
-
-	Word_2_Chars( pak.head.ver, ICQ_VER );
-	Word_2_Chars( pak.head.cmd, CMD_REVERSE_TCP_CONN );
-	Word_2_Chars( pak.head.seq, seq_num++ );
-	DW_2_Chars( pak.head.UIN, our_info->uin );
-
-	DW_2_Chars( data.l_uin, our_info->uin );
-	DW_2_Chars( data.r_uin, uin );
-	DW_2_Chars( data.ip, our_ip );
-	DW_2_Chars( data.porta, port );
-	data.four = 0x04;
-	DW_2_Chars( data.zero, 0x00000000 );
-	DW_2_Chars( data.portb, port );
-	Word_2_Chars( data.version, TCP_VERSION );
-
-	memcpy(&pak.data, &data, sizeof( data ) );
-
-	SOCKWRITE( MainData->sok, &(pak.head.ver), sizeof( data ) + sizeof( pak.head ) - 2 );
-}
-
 void icq_sendurl( GtkWidget *widget, struct URLInfo *data )
 {
 	SIMPLE_MESSAGE msg;
 	net_icq_pak pak;
-	int size, len; 
-	int uin;
-	char *new_text;
-	char *buf;
-	char *text;
+	gint size, len; 
+	UIN_T uin;
+	gchar *new_text;
+	gchar *text;
 
 #ifdef TRACE_FUNCTION
 	g_print( "icq_sendurl\n" );
 #endif
 
-	uin = Contacts[ data->cindex ].uin;
+	uin = ((CONTACT_PTR)data->contact->data)->uin;
 	
-	len = strlen( gtk_entry_get_text( GTK_ENTRY( data->url ) ) ) +
-	      strlen( gtk_entry_get_text( GTK_ENTRY( data->desc ) ) ) + 2;
-
-	text = (char *)g_malloc( len );
-	sprintf( text, "%s\xFE%s", gtk_entry_get_text( GTK_ENTRY( data->desc ) ),
-	         gtk_entry_get_text( GTK_ENTRY( data->url ) ) );
-
+	text = g_strdup_printf( "%s\xFE%s",
+				gtk_entry_get_text( GTK_ENTRY( data->desc ) ),
+				gtk_entry_get_text( GTK_ENTRY( data->url ) ) );
 	new_text = cr_convert( text );
-	buf = (char *)g_malloc( sizeof( char ) * ( 16 + strlen( new_text ) ) );
+	g_free( text );
 
 	/* Add statement to personal history file */
 	add_outgoing_to_history( uin, new_text );
 
-	rus_conv( RUS_KOI_WIN, new_text );
-	if( TCPSendURL( uin, new_text, data->data ) )
+	if( TCPSendURL( uin, new_text ) )
 	{
-		sprintf( buf, "Sent URL (TCP)" );
-		log_window_add( buf, 1, uin );
-		g_free( buf );
+		log_window_add( _("Sent URL (TCP)"), uin );
 		g_free( new_text );
 		return;
 	}
 
-	sprintf( buf, "Sent URL (UDP)" );
-	log_window_add( buf, 1, uin );
-	g_free( buf );
-	rus_conv ( RUS_KOI_WIN, new_text );
+	log_window_add( _("Sent URL (UDP)") , uin );
 	
 	len = strlen(new_text);
 	Word_2_Chars( pak.head.ver, ICQ_VER );
@@ -395,11 +306,7 @@ void icq_sendurl( GtkWidget *widget, struct URLInfo *data )
 
 	size = sizeof( msg ) + len + 1;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( data->data->sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_SENDM(URL)");
 
 	g_free( new_text );
 }
@@ -408,7 +315,7 @@ void icq_sendurl( GtkWidget *widget, struct URLInfo *data )
  * Send an authorization to the server so the
  * client can add the user
  */
-void icq_sendauthmsg( SOK_T sok, DWORD uin)
+void icq_sendauthmsg( UIN_T uin)
 {
 	SIMPLE_MESSAGE msg;
 	net_icq_pak pak;
@@ -434,15 +341,11 @@ void icq_sendauthmsg( SOK_T sok, DWORD uin)
 
 	size = sizeof( msg ) + 2;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "AUTH_MESS");
 }
 
 /* Change User Status */
-void icq_change_status( SOK_T sok, DWORD status, struct sokandlb *data )
+void icq_change_status( DWORD status )
 {
 	net_icq_pak pak;
 	int size ;
@@ -456,27 +359,23 @@ void icq_change_status( SOK_T sok, DWORD status, struct sokandlb *data )
 	Word_2_Chars( pak.head.seq, seq_num++ );
 	DW_2_Chars( pak.head.UIN, our_info->uin );
 
-	DW_2_Chars( pak.data, ( status | 0x10000 ) );
-	Current_Status = status;
+	DW_2_Chars( pak.data, ( status | (toggles->webpresence * 0x10000) ) );
+	Current_Status = status | (toggles->webpresence * 0x10000);
 
 	size = 4;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_STATUS_CHANGE");
 
 	ready_set();
 
-	if( applet_toggle )
+	if( toggles->applet )
 	{
-		applet_update( Current_Status, NULL, data );
+		applet_update( Current_Status, NULL );
 	}
 }
 
 /* Disconnect from ICQ server */
-void Quit_ICQ( int sok )
+void Quit_ICQ( void )
 {
 	net_icq_pak pak;
 	int size, len;
@@ -498,18 +397,14 @@ void Quit_ICQ( int sok )
 	pak.data[ 2 + len ] = 05;
 	pak.data[ 3 + len ] = 00;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "B_USER_DISCONNECTED");
 
-	SOCKCLOSE(sok);
-	SOCKCLOSE( sok );
+	if( MainData->sok )
+		SOCKCLOSE( MainData->sok );
 }
 
 /* Send a request for Info on a User */
-void send_info_req( SOK_T sok, DWORD uin )
+void send_info_req( UIN_T uin )
 {
 	net_icq_pak pak;
 	int size ;
@@ -518,6 +413,9 @@ void send_info_req( SOK_T sok, DWORD uin )
 	g_print( "send_info_req\n" );
 #endif
 
+	info_req_99( uin );
+	return;
+
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_INFO_REQ );
 	Word_2_Chars( pak.head.seq, seq_num++ );
@@ -527,15 +425,13 @@ void send_info_req( SOK_T sok, DWORD uin )
 
 	size = 4;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND ); 
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_INFO_REQ");
 }
 
 /* Start a Server Search for Information Specified */
-void start_search( SOK_T sok, char *email, char *nick, char* first, char* last, DWORD uin )
+void start_search( const gchar *email, const gchar *nick,
+                   const gchar* first, const gchar* last,
+                   UIN_T uin )
 {
 	net_icq_pak pak;
 	int size;
@@ -547,23 +443,15 @@ void start_search( SOK_T sok, char *email, char *nick, char* first, char* last,
 	if( uin > 0 )
 	{
 		start_new_info = TRUE;
-		show_info_new( sok, uin );
+		show_info_new( uin );
 		return;
 	}
 
-	search_wait = show_wait( "Search in Progress", search_pdata );
-	gtk_statusbar_push( GTK_STATUSBAR( statusbar ), 2 + search_wait,
-	                    " Search in Progress..." );
-
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_SEARCH_USER );
 	Word_2_Chars( pak.head.seq, seq_num++ );
 	DW_2_Chars( pak.head.UIN, our_info->uin );
 
-/*
-	Word_2_Chars( pak.data , seq_num++ );
-	size = 2;
-*/
 	size = 0;
 	Word_2_Chars( pak.data + size, strlen( nick ) + 1 );
 	size += 2;
@@ -581,17 +469,14 @@ void start_search( SOK_T sok, char *email, char *nick, char* first, char* last,
 	size += 2;
 	strcpy( pak.data + size , email );
 	size += strlen( email ) + 1;
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_SEARCH_USER");
 }
 
-void send_ext_info_req( SOK_T sok, DWORD uin )
+void send_ext_info_req( UIN_T uin )
 {
 	net_icq_pak pak;
-	int size ;
+	int size;
 
 #ifdef TRACE_FUNCTION
 	g_print( "send_ext_info_req\n" );
@@ -605,14 +490,10 @@ void send_ext_info_req( SOK_T sok, DWORD uin )
 	DW_2_Chars( pak.data, uin );
 	size = 4;
 
-/*
-	packet_print( (pak.head.ver), size + sizeof( pak.head ) - 2,
-	              PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-*/
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_EXT_INFO_REQ");
 }
 
-void reg_new_user( SOK_T sok, char *pass)
+void reg_new_user( const gchar *pass )
 {
 	net_icq_pak pak;
 	char len_buf[2];
@@ -637,84 +518,19 @@ void reg_new_user( SOK_T sok, char *pass)
    DW_2_Chars( &pak.data[14+len], 0x00 );
    size = len + 18;
 
-	DW_2_Chars( pak.head.session, rand() );
+	if( our_session == 0 )
+	{
+		our_session = rand();
+		DW_2_Chars( pak.head.session, our_session );
+		our_session = 0;
+	}
+	else
+		DW_2_Chars( pak.head.session, our_session );
+
 	DW_2_Chars( pak.head.zero, 0L );
 	DW_2_Chars( pak.head.UIN, 0L ); 
          
-	SOCKWRITE_LOW( sok, &( pak.head.ver ), size + sizeof( pak.head ) - 2);
-}
-
-void Gen_Checksum( BYTE * buf, DWORD len )
-{
-   DWORD cc, cc2;
-   DWORD r1,r2;
-   
-   cc = buf[8];
-   cc <<= 8;
-   cc += buf[4];
-   cc <<= 8;
-   cc += buf[2];
-   cc <<= 8;
-   cc += buf[6];
-
-   r1 = rand() % ( len - 0x18 );
-   r1 += 0x18;
-   r2 = rand() & 0xff;
-   
-   cc2 = r1;
-   cc2 <<= 8;
-   cc2 += buf[ r1 ];
-   cc2 <<= 8;
-   cc2 += r2;   
-   cc2 <<= 8;
-   cc2 += table[ r2 ];
-   cc2 ^= 0xff00ff;
-/*   printf( "tbl[%02lX] = %02X\n%08lX\n\n", r2,table[ r2 ], cc ^ cc2 ); */
-   
-   DW_2_Chars( &buf[0x14], cc ^ cc2 );
-}
-
-DWORD Scramble_cc( DWORD cc )
-{
-    DWORD a[6];
-    
-    a[1] = cc & 0x0000001F;
-    a[2] = cc & 0x03E003E0;
-    a[3] = cc & 0xF8000400;
-    a[4] = cc & 0x0000F800;
-    a[5] = cc & 0x041F0000;
-    
-    a[1] <<= 0x0C;
-    a[2] <<= 0x01;
-    a[3] >>= 0x0A;
-    a[4] <<= 0x10;
-    a[5] >>= 0x0F;
-    
-    return a[1] + a[2] + a[3] + a[4] + a[5];
-}
-
-void Wrinkle( void *buf, size_t len )
-{
-	DWORD checkcode;
-	DWORD code1, code2, code3;
-	DWORD pos;
-	DWORD data;
-
-	Gen_Checksum( buf, len );
-	checkcode = Chars_2_DW( &((BYTE*)buf)[ 20 ] );
-	code1 = len * 0x68656c6cL;
-	code2 = code1 + checkcode;
-	pos = 0x0A;
-
-   for ( ; pos < ( len  ); pos+=4 )
-   {
-      code3 = code2 + table[ pos & 0xFF ];
-      data = Chars_2_DW( &((BYTE*)buf)[ pos ] );
-      data ^= code3;
-      DW_2_Chars( &((BYTE*)buf)[ pos ], data );
-   }
-   checkcode = Scramble_cc( checkcode );
-   DW_2_Chars( &((BYTE*)buf)[ 0x14 ], checkcode );
+	SOCKWRITE_LOW( &( pak.head.ver ), size + sizeof( pak.head ) - 2, "CMD_REG_NEW_USER");
 }
 
 /***************************************************************
@@ -723,7 +539,7 @@ When V5 is implemented this will wrinkle the packet and calculate
 the checkcode.
 Adds packet to the queued messages.
 ****************************************************************/
-size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
+size_t SOCKWRITE( void * ptr, size_t len, gchar *charid )
 {
    struct msg *msg_to_queue;
 	static WORD seq2 = 0;
@@ -741,7 +557,7 @@ size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
 	cmd = Chars_2_Word( (((ICQ_PAK_PTR)((BYTE*)ptr-2))->cmd ) );
 	if ( cmd != CMD_ACK && cmd != CMD_SEND_TEXT_CODE )
 	{
-		msg_to_queue = (struct msg *)g_malloc(sizeof(struct msg));
+		msg_to_queue = g_new0( struct msg, 1 );
 		if ( 0 == seq2 )
 		{
 			seq2 = rand() & 0x7fff;
@@ -752,7 +568,6 @@ size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
 		if ( CMD_KEEP_ALIVE == Chars_2_Word( &((BYTE *)ptr)[CMD_OFFSET] ) )
 		{
 			Word_2_Chars( &((BYTE *)ptr)[SEQ2_OFFSET], 0 );
-/*			seq2++;*/
 			seq_num--;
 		}
 
@@ -760,7 +575,7 @@ size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
 
 		msg_to_queue->attempts = 1;
 		msg_to_queue->exp_time = time(NULL) + 10;
-		msg_to_queue->body = (BYTE *)g_malloc( len );
+		msg_to_queue->body = (BYTE *)g_malloc0( len );
 		msg_to_queue->len = len;
 		memcpy(msg_to_queue->body, ptr, msg_to_queue->len);
 		msg_queue_push( msg_to_queue );
@@ -771,44 +586,10 @@ size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
 		}
 	}
 
-   return SOCKWRITE_LOW( sok, ptr, len );
+   return SOCKWRITE_LOW( ptr, len, charid );
 }
 
-
-/***************************************************************
-This handles actually sending a packet after it's been assembled.
-When V5 is implemented this will wrinkle the packet and calculate
-the checkcode.
-****************************************************************/
-static size_t SOCKWRITE_LOW( int sok, void * ptr, size_t len )
-{
-	int retval;
-
-#ifdef TRACE_FUNCTION
-	g_print( "SOCKWRITE_LOW\n" );
-#endif
-
-	if( Connected )
-	 	packet_print( ptr, len, PACKET_TYPE_UDP | PACKET_DIRECTION_SEND );
-
-   Wrinkle( ptr, len );
-
-	if( Connected && MainData->sok > 0 )
-	   retval = sockwrite( sok, ptr, len );
-	else
-		retval = FALSE;
-
-	/* -1 means we have a problem, so figure we're not connected */
-/*
-	if( retval == -1 && Done_Login )
-	{
-		icq_set_status_offline( NULL, MainData );
-	}
-*/
-	return retval; 
-}
-
-size_t SOCKREAD( SOK_T sok, void * ptr, size_t len )
+size_t SOCKREAD( void * ptr, size_t len )
 {
    size_t sz;
 
@@ -816,11 +597,11 @@ size_t SOCKREAD( SOK_T sok, void * ptr, size_t len )
 	g_print( "SOCKREAD\n" );
 #endif
 
-   sz = sockread( sok, ptr, len );
+   sz = sockread( MainData->sok, ptr, len );
    return sz;
 }
 
-void Update_User_Info( SOK_T sok )
+void Update_User_Info( void )
 {
 	net_icq_pak pak;
 	int size ;
@@ -850,7 +631,7 @@ void Update_User_Info( SOK_T sok )
    pak.data[ size ] = our_info->auth;
    size++;
 
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_UPDATE_INFO");
 
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_AUTH_UPDATE );
@@ -859,7 +640,7 @@ void Update_User_Info( SOK_T sok )
 
    DW_2_Chars( pak.data, ! our_info->auth );
 
-	SOCKWRITE( sok, &(pak.head.ver), 4 + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), 4 + sizeof( pak.head ) - 2, "CMD_AUTH_UPDATE");
 
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_META_USER );
@@ -920,10 +701,10 @@ void Update_User_Info( SOK_T sok )
    size += 4;
    Word_2_Chars( &pak.data[ size ] , our_info->country );
    size += 2;
-   pak.data[ size ++ ] = (BYTE)our_info->c_status;
+   pak.data[ size ] = (BYTE)((our_info->c_status/100)*2 );
    pak.data[ size++ ] = our_info->hide_email;
 
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_META_USER(META_INFO_SET)");
 
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_META_USER );
@@ -932,9 +713,12 @@ void Update_User_Info( SOK_T sok )
    
    Word_2_Chars( pak.data , META_INFO_HOMEPAGE );
    size = 2;
-	pak.data[ size ++ ] = (BYTE)our_info->age;
-	Word_2_Chars( pak.data + size, 0x0200 );
-	size += 2;	
+/*	pak.data[ size ++ ] = (BYTE)our_info->age;
+	Word_2_Chars( pak.data + size, our_info->sex );
+	Word_2_Chars( pak.data + size, 0x0200 );*/
+	Word_2_Chars( pak.data + size, our_info->age );
+	size += 2;
+	pak.data[ size++ ] = (BYTE)our_info->sex;
 	Word_2_Chars( pak.data + size, strlen( our_info->homepage ) + 1 );
 	size += 2;
 	strcpy( pak.data + size, our_info->homepage );
@@ -947,7 +731,7 @@ void Update_User_Info( SOK_T sok )
 	pak.data[ size ++ ] = 0xff;
 	pak.data[ size ++ ] = 0xff;
 
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_META_USER(META_INFO_HOMEPAGE)");
 
 	Word_2_Chars( pak.head.ver, ICQ_VER );
 	Word_2_Chars( pak.head.cmd, CMD_META_USER );
@@ -959,7 +743,180 @@ void Update_User_Info( SOK_T sok )
 	Word_2_Chars( pak.data + size, strlen( cr_convert( our_info->about ) ) + 1 );
 	size += 2;
 	strcpy( pak.data + size, cr_convert( our_info->about ) );
-	size += strlen( cr_convert( our_info->about ) );
+	size += strlen( cr_convert( our_info->about ) ) + 1;
 
-	SOCKWRITE( sok, &(pak.head.ver), size + sizeof( pak.head ) - 2);
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_META_USER(META_INFO_ABOUT)");
+}
+
+void info_req_99( UIN_T uin )
+{
+	GSList *contact;
+	CONTACT_PTR our_contact;
+	net_icq_pak pak;
+	int size;
+
+	contact = Contacts;
+
+	while( contact != NULL )
+	{
+		if( ((CONTACT_PTR)contact->data)->uin == uin )
+			break;
+		contact = contact->next;
+	}
+
+	if( contact == NULL )
+	{
+		our_contact = &New_Contact;
+		our_contact->uin = uin;
+	}
+	else
+		our_contact = (CONTACT_PTR)contact->data;
+
+	our_contact->info_seq = seq_num;
+
+	Word_2_Chars( pak.head.ver, ICQ_VER );
+	Word_2_Chars( pak.head.cmd, CMD_META_USER );
+	Word_2_Chars( pak.head.seq, seq_num++ );
+	DW_2_Chars( pak.head.UIN, our_info->uin );
+	Word_2_Chars( pak.data, META_INFO_REQ );
+	DW_2_Chars( pak.data + 2, uin );
+
+	size = 6;
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_META_USER(META_INFO_REQ)" );
+}
+
+/*** Local functions ***/
+gchar *cr_convert( const gchar *text )
+{
+	char *t;
+	int cx, cy;
+	
+	cy = 0;
+	for( cx = 0; cx < strlen( text ); cx ++ )
+	{
+		if( text[ cx ] == '\n' )
+			cy ++;
+	}
+	
+	t = g_malloc( strlen( text ) + cy + 1 );
+
+	cy = 0;
+	for( cx = 0; cx < strlen( text ); cx ++ )
+	{
+		if( text[ cx ] != '\n' )
+			t[ cy ++ ] = text[ cx ];
+		else
+		{
+			t[ cy ++ ] = '\r';
+			t[ cy ++ ] = '\n';
+		}
+	}
+
+	t[ cy ] = 0x00;
+	
+	return t;
+}
+
+void Wrinkle( void *buf, size_t len )
+{
+	DWORD checkcode;
+	DWORD code1, code2, code3;
+	DWORD pos;
+	DWORD data;
+
+	Gen_Checksum( buf, len );
+	checkcode = Chars_2_DW( &((BYTE*)buf)[ 20 ] );
+	code1 = len * 0x68656c6cL;
+	code2 = code1 + checkcode;
+	pos = 0x0A;
+
+   for ( ; pos < ( len  ); pos+=4 )
+   {
+      code3 = code2 + table[ pos & 0xFF ];
+      data = Chars_2_DW( &((BYTE*)buf)[ pos ] );
+      data ^= code3;
+      DW_2_Chars( &((BYTE*)buf)[ pos ], data );
+   }
+   checkcode = Scramble_cc( checkcode );
+   DW_2_Chars( &((BYTE*)buf)[ 0x14 ], checkcode );
+}
+
+void Gen_Checksum( BYTE * buf, DWORD len )
+{
+   DWORD cc, cc2;
+   DWORD r1,r2;
+   
+   cc = buf[8];
+   cc <<= 8;
+   cc += buf[4];
+   cc <<= 8;
+   cc += buf[2];
+   cc <<= 8;
+   cc += buf[6];
+
+   r1 = rand() % ( len - 0x18 );
+   r1 += 0x18;
+   r2 = rand() & 0xff;
+   
+   cc2 = r1;
+   cc2 <<= 8;
+   cc2 += buf[ r1 ];
+   cc2 <<= 8;
+   cc2 += r2;   
+   cc2 <<= 8;
+   cc2 += table[ r2 ];
+   cc2 ^= 0xff00ff;
+/*   printf( "tbl[%02lX] = %02X\n%08lX\n\n", r2,table[ r2 ], cc ^ cc2 ); */
+   
+   DW_2_Chars( &buf[0x14], cc ^ cc2 );
+}
+
+DWORD Scramble_cc( DWORD cc )
+{
+    DWORD a[6];
+    
+    a[1] = cc & 0x0000001F;
+    a[2] = cc & 0x03E003E0;
+    a[3] = cc & 0xF8000400;
+    a[4] = cc & 0x0000F800;
+    a[5] = cc & 0x041F0000;
+    
+    a[1] <<= 0x0C;
+    a[2] <<= 0x01;
+    a[3] >>= 0x0A;
+    a[4] <<= 0x10;
+    a[5] >>= 0x0F;
+    
+    return a[1] + a[2] + a[3] + a[4] + a[5];
+}
+
+/***************************************************************
+This handles actually sending a packet after it's been assembled.
+When V5 is implemented this will wrinkle the packet and calculate
+the checkcode.
+****************************************************************/
+static size_t SOCKWRITE_LOW( void * ptr, size_t len, gchar *charid )
+{
+	int retval;
+
+#ifdef TRACE_FUNCTION
+	g_print( "SOCKWRITE_LOW\n" );
+#endif
+
+/*	if( Connected )*/
+	 	packet_print( ptr, len, PACKET_TYPE_UDP | PACKET_DIRECTION_SEND, charid );
+
+   Wrinkle( ptr, len );
+
+	if( Connected && MainData->sok > 0 )
+	   retval = sockwrite( MainData->sok, ptr, len );
+	else
+		retval = FALSE;
+
+	/* -1 means we have a problem, so figure we're not connected */
+/*
+	if( retval == -1 && Done_Login )
+		icq_set_status_offline( NULL );
+*/
+	return retval; 
 }
